@@ -1,2 +1,2 @@
 def say_something():
-    print('Hello')
\ No newline at end of file
+    return 'Hi'
\ No newline at end of file
